import { Path } from "./util";
export declare const DEFAULT_COL = "path";
export interface IContentRow {
    path: Path.PathArray;
    kind: "dir" | string;
    getChildren?: () => Promise<IContentRow[]>;
}
export declare class Content<T extends IContentRow> {
    constructor({ row, filterer, sorter }: {
        row: T;
        filterer?: Content.Filterer<T>;
        sorter?: Content.Sorter<T>;
    });
    init({ row, filterer, sorter }: {
        row: T;
        filterer?: Content.Filterer<T>;
        sorter?: Content.Sorter<T>;
    }): this;
    collapse(): void;
    equalPath(otherPath: Path.PathArray): boolean;
    expand(): Promise<void>;
    getChildren(): Promise<Content<T>[] | undefined>;
    getPathAtDepth(depth?: number, fill?: string): any[];
    protected _flatten(_flat?: Content<T>[]): Promise<Content<T>[]>;
    flatten(): Promise<Content<T>[]>;
    /**
     * If _recursive, mark any subcache as invalid as well
     */
    invalidate(_recursive?: boolean): void;
    get hasChildren(): boolean;
    get isExpand(): boolean;
    get nchildren(): number;
    get name(): string;
    get pathstr(): string;
    get row(): T;
    set row(row: T);
    set filterer(filterer: Content.Filterer<T> | undefined);
    set sorter(sorter: Content.Sorter<T> | undefined);
    protected get _dirty(): boolean;
    protected _row: T;
    protected _hasChildren: boolean;
    protected _isExpand: boolean;
    protected _name: string;
    protected _pathstr: string;
    protected _cache?: Content<T>[];
    protected _cacheMap?: Map<string, Content<T>>;
    protected _dirtyChildren: boolean;
    protected _dirtySort: boolean;
    protected _filterer?: Content.Filterer<T>;
    protected _sorter?: Content.Sorter<T>;
}
export declare namespace Content {
    type Filterer<T extends IContentRow> = (c: Content<T>) => boolean;
    type Sorter<T extends IContentRow> = (l: Content<T>, r: Content<T>) => number;
    function blank<T extends IContentRow>(cols: (keyof T)[]): Content<T>;
}
//# sourceMappingURL=content.d.ts.map